Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(223)

Unified Diff: media/base/mime_util_internal.h

Issue 1896983004: Rename misleading |is_ambiguous| parameter Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: update VP9 comment to match Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/base/mime_util_internal.cc » ('j') | media/base/mime_util_internal.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/mime_util_internal.h
diff --git a/media/base/mime_util_internal.h b/media/base/mime_util_internal.h
index b96c91368a0a51942c0c537e0674d22f20d8d1fb..37e4a9012f936c6388fd93f01d3878ce8dcf5eba 100644
--- a/media/base/mime_util_internal.h
+++ b/media/base/mime_util_internal.h
@@ -98,31 +98,36 @@ class MEDIA_EXPORT MimeUtil {
const CodecSet& codecs_list,
bool is_proprietary_mime_type);
- // Returns IsSupported if all codec IDs in |codecs| are unambiguous and are
- // supported in |mime_type_lower_case|. MayBeSupported is returned if at least
- // one codec ID in |codecs| is ambiguous but all the codecs are supported.
- // IsNotSupported is returned if |mime_type_lower_case| is not supported or at
- // least one is not supported in |mime_type_lower_case|. |is_encrypted| means
- // the codec will be used with encrypted blocks.
+ // Returns IsSupported if all codec IDs in |codecs| are unambiguous,
+ // are supported in |mime_type_lower_case|, and can probably be decoded.
+ // Returns MayBeSupported if all the codec IDs in |codecs| are supported in
+ // |mime_type_lower_case| but at least one codec ID is ambiguous or may not
+ // be supported by the decoder(s). IsNotSupported is returned if
+ // |mime_type_lower_case| is not supported or at least one of the codec IDs in
+ // |codecs| is not supported in |mime_type_lower_case|. |supported_codecs|
+ // provides the list of codecs allowed in |mime_type_lower_case|.
+ // |is_encrypted| means the codec will be used with encrypted blocks.
SupportsType AreSupportedCodecs(const CodecSet& supported_codecs,
const std::vector<std::string>& codecs,
const std::string& mime_type_lower_case,
bool is_encrypted) const;
// Converts a codec ID into an Codec enum value and indicates
// whether the conversion was ambiguous.
// Returns true if this method was able to map |codec_id| with
// |mime_type_lower_case| to a specific Codec enum value. |codec| and
// |is_ambiguous| are only valid if true is returned. Otherwise their value is
// undefined after the call.
// |is_ambiguous| is true if |codec_id| did not have enough information to
// unambiguously determine the proper Codec enum value. If |is_ambiguous|
// is true |codec| contains the best guess for the intended Codec enum value.
// |is_encrypted| means the codec will be used with encrypted blocks.
bool StringToCodec(const std::string& mime_type_lower_case,
const std::string& codec_id,
Codec* codec,
- bool* is_ambiguous,
+ bool* is_known_supported,
bool is_encrypted) const;
// Returns true if |codec| is supported when contained in
« no previous file with comments | « no previous file | media/base/mime_util_internal.cc » ('j') | media/base/mime_util_internal.cc » ('J')
@@ -98,31 +98,36 @@ class MEDIA_EXPORT MimeUtil {
const std::string& mime_type_lower_case,
bool is_encrypted) const;
- // Converts a codec ID into an Codec enum value and indicates
- // whether the conversion was ambiguous.
- // Returns true if this method was able to map |codec_id| with
- // |mime_type_lower_case| to a specific Codec enum value. |codec| and
- // |is_ambiguous| are only valid if true is returned. Otherwise their value is
- // undefined after the call.
- // |is_ambiguous| is true if |codec_id| did not have enough information to
- // unambiguously determine the proper Codec enum value. If |is_ambiguous|
- // is true |codec| contains the best guess for the intended Codec enum value.
- // |is_encrypted| means the codec will be used with encrypted blocks.
+ // Converts a codec ID into a Codec enum value and indicates whether the
+ // specified codec, including profile, etc., is probably supported.
+ // Returns true if this method was able to map |codec_id|, interpreted for
+ // |mime_type_lower_case|, to a specific Codec enum value. If so, |codec|
+ // contains the resulting value and |is_known_supported| indicates whether
+ // decoding of content represented by the codec ID is probably supported
+ // (true) or there is not confidence that such content can be decoded (false).
+ // Examples of the latter include ambiguous codec IDs (those in
+ // kAmbiguousCodecStringMap) and profiles that are not definitively known to
+ // be supported. |codec| and |is_known_supported| are only valid if true is
+ // returned; otherwise their value is undefined. |is_encrypted| means the
+ // codec will be used with encrypted blocks.
bool StringToCodec(const std::string& mime_type_lower_case,
const std::string& codec_id,

Powered by Google App Engine
This is Rietveld 408576698